# Table of Contents

- [reports-and-roadmaps](<./reports-and-roadmaps.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Reports and Roadmaps](<./Reports-and-Roadmaps.md>)
  - [Visualizing Future Changes of Transformations](<./Reports-and-Roadmaps/Visualizing-Future-Changes-of-Transformations.md>)
  - [Roadmap Reports in SAP LeanIX Architecture and Road Map Planning](<./Reports-and-Roadmaps/Roadmap-Reports-in-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Visualize Dependencies](<./Reports-and-Roadmaps/Visualize-Dependencies.md>)
